
/* Chrysalide - Outil d'analyse de fichiers binaires
 * file.c - prototypes pour l'équivalent Python du fichier "analysis/contents/file.c"
 *
 * Copyright (C) 2015 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  OpenIDA is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  OpenIDA is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#include "file.h"


#include <pygobject.h>


#include <analysis/contents/file.h>



/* Crée un nouvel objet Python de type 'BinContent'. */
static PyObject *py_file_content_new(PyTypeObject *, PyObject *, PyObject *);



/******************************************************************************
*                                                                             *
*  Paramètres  : type = type de l'objet à instancier.                         *
*                args = arguments fournis à l'appel.                          *
*                kwds = arguments de type key=val fournis.                    *
*                                                                             *
*  Description : Crée un nouvel objet Python de type 'BinContent'.            *
*                                                                             *
*  Retour      : Instance Python mise en place.                               *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

static PyObject *py_file_content_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
{
    PyObject *result;                       /* Instance à retourner        */
    const char *filename;                   /* Nom du fichier à charger    */
    int ret;                                /* Bilan de lecture des args.  */
    GBinContent *content;                   /* Version GLib du contenu     */

    ret = PyArg_ParseTuple(args, "s", &filename);
    if (!ret) Py_RETURN_NONE;

    content = g_file_content_new(filename);

    result = pygobject_new(G_OBJECT(content));

    if (content != NULL)
        g_object_unref(content);

    return result;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : -                                                            *
*                                                                             *
*  Description : Fournit un accès à une définition de type à diffuser.        *
*                                                                             *
*  Retour      : Définition d'objet pour Python.                              *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/



PyMethodDef py_file_content_methods[] = {
    { NULL }
};

PyGetSetDef py_file_content_getseters[] = {
    { NULL }
};

PyTypeObject py_file_content_type = {

    PyVarObject_HEAD_INIT(NULL, 0)

    .tp_name        = "pychrysalide.analysis.contents.FileContent",
    .tp_basicsize   = sizeof(PyGObject),

    .tp_flags       = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,

    .tp_doc         = "PyChrysalide binary file content",

    /*
      .tp_methods     = py_file_content_methods,
      .tp_getset      = py_file_content_getseters,
      .tp_new         = (newfunc)py_file_content_new
    */
    .tp_new         = (newfunc)py_file_content_new

};



PyTypeObject *get_python_file_content_type(void)
{
#if 0
    static PyMethodDef py_file_content_methods[] = {
        { NULL }
    };

    static PyGetSetDef py_file_content_getseters[] = {
        { NULL }
    };

    static PyTypeObject py_file_content_type = {

        PyVarObject_HEAD_INIT(NULL, 0)

        .tp_name        = "pychrysalide.analysis.contents.FileContent",
        .tp_basicsize   = sizeof(PyGObject),

        .tp_flags       = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | 1 << 9,

        .tp_doc         = "PyChrysalide binary file content",

        /*
        .tp_methods     = py_file_content_methods,
        .tp_getset      = py_file_content_getseters,
        .tp_new         = (newfunc)py_file_content_new
        */

    };
#endif
    return &py_file_content_type;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : module = module dont la définition est à compléter.          *
*                                                                             *
*  Description : Prend en charge l'objet 'pychrysalide.glibext.BinContent'.   *
*                                                                             *
*  Retour      : Bilan de l'opération.                                        *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/
#include "../content.h"//////////////////////////////////////////
bool register_python_file_content(PyObject *module)
{
    PyTypeObject *py_file_content_type;   /* Type Python 'BinContent'    */
    int ret;                                /* Bilan d'un appel            */
    PyObject *dict;                         /* Dictionnaire du module      */

    py_file_content_type = get_python_file_content_type();

    //py_file_content_type->tp_base = &PyGObject_Type;
    //py_file_content_type->tp_basicsize = py_file_content_type->tp_base->tp_basicsize;

    /*
    if (PyType_Ready(py_file_content_type) != 0)
        return false;
    */

    /*
    Py_INCREF(py_file_content_type);
    ret = PyModule_AddObject(module, "FileContent", (PyObject *)py_file_content_type);
    if (ret != 0) return false;
    */

    dict = PyModule_GetDict(module);
    pygobject_register_class(dict, "FileContent", G_TYPE_FILE_CONTENT, py_file_content_type,
                             Py_BuildValue("(O)", &PyGObject_Type/*py_file_content_type->tp_base*/,
                                   get_python_binary_content_type()));

    /*
    if (PyType_Ready(py_file_content_type) != 0)
        return false;
    */


    return true;

}
